webhook2pushover

package module
v0.0.0-...-b287e3c Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 18, 2021 License: MIT Imports: 6 Imported by: 0

README

webhook2pushover

Google Cloud Function which acts as a simple endpoint for receiving a webhook and forward it as a Pushover Notification

needed environment variables

variable description
TOKEN The Pushover auth token
USER The Pushover user

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Handle

func Handle(w http.ResponseWriter, r *http.Request)

Handle will handle the cloud function call

Types

This section is empty.

Jump to